pub struct RemoteExecutionEvidence {
pub served_model: Option<String>,
pub provider_response_id: Option<String>,
pub provider_request_id: Option<String>,
pub reasoning_output_tokens: Option<u64>,
pub provider_finish_reason: Option<String>,
}Fields
served_model: Option<String>provider_response_id: Option<String>provider_request_id: Option<String>reasoning_output_tokens: Option<u64>provider_finish_reason: Option<String>Trait Implementations
Sourceimpl Clone for RemoteExecutionEvidence
impl Clone for RemoteExecutionEvidence
Sourcefn clone(&self) -> RemoteExecutionEvidence
fn clone(&self) -> RemoteExecutionEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteExecutionEvidence
impl Debug for RemoteExecutionEvidence
Sourceimpl Default for RemoteExecutionEvidence
impl Default for RemoteExecutionEvidence
Sourcefn default() -> RemoteExecutionEvidence
fn default() -> RemoteExecutionEvidence
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteExecutionEvidence
impl<'de> Deserialize<'de> for RemoteExecutionEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteExecutionEvidence
Sourceimpl JsonSchema for RemoteExecutionEvidence
impl JsonSchema for RemoteExecutionEvidence
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteExecutionEvidence
impl PartialEq for RemoteExecutionEvidence
Sourceimpl Serialize for RemoteExecutionEvidence
impl Serialize for RemoteExecutionEvidence
impl StructuralPartialEq for RemoteExecutionEvidence