pub struct RemoteReasoningCapability {
pub efforts: Vec<String>,
pub default_effort: Option<String>,
pub aliases: BTreeMap<String, String>,
pub encoding: RemoteReasoningEncoding,
pub mandatory: bool,
}Expand description
Mirror of the core ReasoningCapability.
Fields
efforts: Vec<String>default_effort: Option<String>aliases: BTreeMap<String, String>encoding: RemoteReasoningEncodingmandatory: boolTrait Implementations
Sourceimpl Clone for RemoteReasoningCapability
impl Clone for RemoteReasoningCapability
Sourcefn clone(&self) -> RemoteReasoningCapability
fn clone(&self) -> RemoteReasoningCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteReasoningCapability
impl Debug for RemoteReasoningCapability
Sourceimpl Default for RemoteReasoningCapability
impl Default for RemoteReasoningCapability
Sourcefn default() -> RemoteReasoningCapability
fn default() -> RemoteReasoningCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteReasoningCapability
impl<'de> Deserialize<'de> for RemoteReasoningCapability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteReasoningCapability
Sourceimpl JsonSchema for RemoteReasoningCapability
impl JsonSchema for RemoteReasoningCapability
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RemoteReasoningCapability