pub struct RemoteSchemaContract {
pub canonical: Value,
pub projection: RemoteSchemaProjectionPolicy,
}Fields
canonical: Valueprojection: RemoteSchemaProjectionPolicyTrait Implementations
Sourceimpl Clone for RemoteSchemaContract
impl Clone for RemoteSchemaContract
Sourcefn clone(&self) -> RemoteSchemaContract
fn clone(&self) -> RemoteSchemaContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteSchemaContract
impl Debug for RemoteSchemaContract
Sourceimpl Default for RemoteSchemaContract
impl Default for RemoteSchemaContract
Sourceimpl<'de> Deserialize<'de> for RemoteSchemaContract
impl<'de> Deserialize<'de> for RemoteSchemaContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteSchemaContract
Sourceimpl JsonSchema for RemoteSchemaContract
impl JsonSchema for RemoteSchemaContract
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteSchemaContract
impl PartialEq for RemoteSchemaContract
Sourcefn eq(&self, other: &RemoteSchemaContract) -> bool
fn eq(&self, other: &RemoteSchemaContract) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteSchemaContract
impl Serialize for RemoteSchemaContract
impl StructuralPartialEq for RemoteSchemaContract