pub struct RemoteAbandonEvidence {
pub writer: RemoteAbandonWriter,
pub owner: Option<Value>,
pub epoch_ms: u64,
}Expand description
Wire mirror of Abandoned-terminal evidence. The dead/lapsed owner identity is carried opaquely (the wire has no lease-owner mirror), matching how other nested core types ride the wire as JSON.
Fields
writer: RemoteAbandonWriterowner: Option<Value>epoch_ms: u64Trait Implementations
Sourceimpl Clone for RemoteAbandonEvidence
impl Clone for RemoteAbandonEvidence
Sourcefn clone(&self) -> RemoteAbandonEvidence
fn clone(&self) -> RemoteAbandonEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteAbandonEvidence
impl Debug for RemoteAbandonEvidence
Sourceimpl<'de> Deserialize<'de> for RemoteAbandonEvidence
impl<'de> Deserialize<'de> for RemoteAbandonEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteAbandonEvidence
impl JsonSchema for RemoteAbandonEvidence
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteAbandonEvidence
impl PartialEq for RemoteAbandonEvidence
Sourcefn eq(&self, other: &RemoteAbandonEvidence) -> bool
fn eq(&self, other: &RemoteAbandonEvidence) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteAbandonEvidence
impl Serialize for RemoteAbandonEvidence
impl StructuralPartialEq for RemoteAbandonEvidence