pub struct RemoteAbandonRequest {
pub requested_by: String,
pub requested_at_ms: u64,
pub reason: Option<String>,
}Expand description
Wire mirror of the pending Abandon Request marker.
Fields
requested_by: Stringrequested_at_ms: u64reason: Option<String>Trait Implementations
Sourceimpl Clone for RemoteAbandonRequest
impl Clone for RemoteAbandonRequest
Sourcefn clone(&self) -> RemoteAbandonRequest
fn clone(&self) -> RemoteAbandonRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteAbandonRequest
impl Debug for RemoteAbandonRequest
Sourceimpl<'de> Deserialize<'de> for RemoteAbandonRequest
impl<'de> Deserialize<'de> for RemoteAbandonRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteAbandonRequest
impl JsonSchema for RemoteAbandonRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteAbandonRequest
impl PartialEq for RemoteAbandonRequest
Sourcefn eq(&self, other: &RemoteAbandonRequest) -> bool
fn eq(&self, other: &RemoteAbandonRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteAbandonRequest
impl Serialize for RemoteAbandonRequest
impl StructuralPartialEq for RemoteAbandonRequest