pub struct RemoteProcessStarted {
pub owner: Value,
pub started_at_ms: u64,
}Expand description
Wire mirror of the durable execution-started fact.
Fields
owner: Valuestarted_at_ms: u64Trait Implementations
Sourceimpl Clone for RemoteProcessStarted
impl Clone for RemoteProcessStarted
Sourcefn clone(&self) -> RemoteProcessStarted
fn clone(&self) -> RemoteProcessStarted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteProcessStarted
impl Debug for RemoteProcessStarted
Sourceimpl<'de> Deserialize<'de> for RemoteProcessStarted
impl<'de> Deserialize<'de> for RemoteProcessStarted
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteProcessStarted
impl JsonSchema for RemoteProcessStarted
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteProcessStarted
impl PartialEq for RemoteProcessStarted
Sourcefn eq(&self, other: &RemoteProcessStarted) -> bool
fn eq(&self, other: &RemoteProcessStarted) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteProcessStarted
impl Serialize for RemoteProcessStarted
impl StructuralPartialEq for RemoteProcessStarted