pub struct RemoteAttachmentRef {
pub id: String,
pub mime: String,
pub byte_len: u64,
pub width: Option<u32>,
pub height: Option<u32>,
pub label: Option<String>,
pub metadata: HashMap<String, String>,
}Fields
id: Stringmime: Stringbyte_len: u64width: Option<u32>height: Option<u32>label: Option<String>metadata: HashMap<String, String>Trait Implementations
Sourceimpl Clone for RemoteAttachmentRef
impl Clone for RemoteAttachmentRef
Sourcefn clone(&self) -> RemoteAttachmentRef
fn clone(&self) -> RemoteAttachmentRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteAttachmentRef
impl Debug for RemoteAttachmentRef
Sourceimpl<'de> Deserialize<'de> for RemoteAttachmentRef
impl<'de> Deserialize<'de> for RemoteAttachmentRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteAttachmentRef
Sourceimpl JsonSchema for RemoteAttachmentRef
impl JsonSchema for RemoteAttachmentRef
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteAttachmentRef
impl PartialEq for RemoteAttachmentRef
Sourcefn eq(&self, other: &RemoteAttachmentRef) -> bool
fn eq(&self, other: &RemoteAttachmentRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteAttachmentRef
impl Serialize for RemoteAttachmentRef
impl StructuralPartialEq for RemoteAttachmentRef