pub struct RemoteCallPathBinding {
pub module_path: Vec<String>,
pub operation: String,
}Fields
module_path: Vec<String>operation: StringTrait Implementations
Sourceimpl Clone for RemoteCallPathBinding
impl Clone for RemoteCallPathBinding
Sourcefn clone(&self) -> RemoteCallPathBinding
fn clone(&self) -> RemoteCallPathBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteCallPathBinding
impl Debug for RemoteCallPathBinding
Sourceimpl<'de> Deserialize<'de> for RemoteCallPathBinding
impl<'de> Deserialize<'de> for RemoteCallPathBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteCallPathBinding
Sourceimpl JsonSchema for RemoteCallPathBinding
impl JsonSchema for RemoteCallPathBinding
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteCallPathBinding
impl PartialEq for RemoteCallPathBinding
Sourcefn eq(&self, other: &RemoteCallPathBinding) -> bool
fn eq(&self, other: &RemoteCallPathBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteCallPathBinding
impl Serialize for RemoteCallPathBinding
impl StructuralPartialEq for RemoteCallPathBinding