pub struct RemoteDiagnostic {
pub kind: String,
pub code: Option<String>,
pub message: String,
pub data: Option<Value>,
}Fields
kind: Stringcode: Option<String>message: Stringdata: Option<Value>Trait Implementations
Sourceimpl Clone for RemoteDiagnostic
impl Clone for RemoteDiagnostic
Sourcefn clone(&self) -> RemoteDiagnostic
fn clone(&self) -> RemoteDiagnostic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteDiagnostic
impl Debug for RemoteDiagnostic
Sourceimpl Default for RemoteDiagnostic
impl Default for RemoteDiagnostic
Sourcefn default() -> RemoteDiagnostic
fn default() -> RemoteDiagnostic
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteDiagnostic
impl<'de> Deserialize<'de> for RemoteDiagnostic
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteDiagnostic
Sourceimpl JsonSchema for RemoteDiagnostic
impl JsonSchema for RemoteDiagnostic
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteDiagnostic
impl PartialEq for RemoteDiagnostic
Sourcefn eq(&self, other: &RemoteDiagnostic) -> bool
fn eq(&self, other: &RemoteDiagnostic) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteDiagnostic
impl Serialize for RemoteDiagnostic
impl StructuralPartialEq for RemoteDiagnostic