pub struct RemoteExecutionSummary {
pub had_tool_calls: bool,
pub had_code_execution: bool,
}Fields
had_tool_calls: boolhad_code_execution: boolTrait Implementations
Sourceimpl Clone for RemoteExecutionSummary
impl Clone for RemoteExecutionSummary
Sourcefn clone(&self) -> RemoteExecutionSummary
fn clone(&self) -> RemoteExecutionSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteExecutionSummary
impl Debug for RemoteExecutionSummary
Sourceimpl Default for RemoteExecutionSummary
impl Default for RemoteExecutionSummary
Sourcefn default() -> RemoteExecutionSummary
fn default() -> RemoteExecutionSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteExecutionSummary
impl<'de> Deserialize<'de> for RemoteExecutionSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteExecutionSummary
Sourceimpl JsonSchema for RemoteExecutionSummary
impl JsonSchema for RemoteExecutionSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteExecutionSummary
impl PartialEq for RemoteExecutionSummary
Sourcefn eq(&self, other: &RemoteExecutionSummary) -> bool
fn eq(&self, other: &RemoteExecutionSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteExecutionSummary
impl Serialize for RemoteExecutionSummary
impl StructuralPartialEq for RemoteExecutionSummary