pub struct RemoteLlmAttachment {
pub id: Option<String>,
pub mime: String,
pub data_base64: Option<String>,
pub reference: Option<RemoteAttachmentRef>,
pub metadata: HashMap<String, String>,
}Fields
id: Option<String>mime: Stringdata_base64: Option<String>reference: Option<RemoteAttachmentRef>metadata: HashMap<String, String>Trait Implementations
Sourceimpl Clone for RemoteLlmAttachment
impl Clone for RemoteLlmAttachment
Sourcefn clone(&self) -> RemoteLlmAttachment
fn clone(&self) -> RemoteLlmAttachment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteLlmAttachment
impl Debug for RemoteLlmAttachment
Sourceimpl<'de> Deserialize<'de> for RemoteLlmAttachment
impl<'de> Deserialize<'de> for RemoteLlmAttachment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteLlmAttachment
Sourceimpl JsonSchema for RemoteLlmAttachment
impl JsonSchema for RemoteLlmAttachment
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteLlmAttachment
impl PartialEq for RemoteLlmAttachment
Sourcefn eq(&self, other: &RemoteLlmAttachment) -> bool
fn eq(&self, other: &RemoteLlmAttachment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteLlmAttachment
impl Serialize for RemoteLlmAttachment
impl StructuralPartialEq for RemoteLlmAttachment