pub struct RemoteLlmMessage {
pub role: RemoteLlmRole,
pub content: Vec<RemoteLlmContentBlock>,
}Fields
role: RemoteLlmRolecontent: Vec<RemoteLlmContentBlock>Trait Implementations
Sourceimpl Clone for RemoteLlmMessage
impl Clone for RemoteLlmMessage
Sourcefn clone(&self) -> RemoteLlmMessage
fn clone(&self) -> RemoteLlmMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteLlmMessage
impl Debug for RemoteLlmMessage
Sourceimpl<'de> Deserialize<'de> for RemoteLlmMessage
impl<'de> Deserialize<'de> for RemoteLlmMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteLlmMessage
Sourceimpl JsonSchema for RemoteLlmMessage
impl JsonSchema for RemoteLlmMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteLlmMessage
impl PartialEq for RemoteLlmMessage
Sourcefn eq(&self, other: &RemoteLlmMessage) -> bool
fn eq(&self, other: &RemoteLlmMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteLlmMessage
impl Serialize for RemoteLlmMessage
impl StructuralPartialEq for RemoteLlmMessage