pub struct RemoteLlmToolSpec {
pub name: String,
pub description: String,
pub input_schema: Value,
pub output_schema: Value,
pub input_schema_projections: Vec<RemoteSchemaProjectionOverride>,
pub output_schema_projections: Vec<RemoteSchemaProjectionOverride>,
}Fields
name: Stringdescription: Stringinput_schema: Valueoutput_schema: Valueinput_schema_projections: Vec<RemoteSchemaProjectionOverride>output_schema_projections: Vec<RemoteSchemaProjectionOverride>Trait Implementations
Sourceimpl Clone for RemoteLlmToolSpec
impl Clone for RemoteLlmToolSpec
Sourcefn clone(&self) -> RemoteLlmToolSpec
fn clone(&self) -> RemoteLlmToolSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteLlmToolSpec
impl Debug for RemoteLlmToolSpec
Sourceimpl<'de> Deserialize<'de> for RemoteLlmToolSpec
impl<'de> Deserialize<'de> for RemoteLlmToolSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteLlmToolSpec
Sourceimpl JsonSchema for RemoteLlmToolSpec
impl JsonSchema for RemoteLlmToolSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteLlmToolSpec
impl PartialEq for RemoteLlmToolSpec
Sourcefn eq(&self, other: &RemoteLlmToolSpec) -> bool
fn eq(&self, other: &RemoteLlmToolSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteLlmToolSpec
impl Serialize for RemoteLlmToolSpec
impl StructuralPartialEq for RemoteLlmToolSpec