pub struct RemotePromptContribution {
pub slot: RemotePromptSlot,
pub title: Option<String>,
pub priority: i32,
pub gate: RemotePromptContributionGate,
pub content: String,
}Fields
slot: RemotePromptSlottitle: Option<String>priority: i32gate: RemotePromptContributionGatecontent: StringTrait Implementations
Sourceimpl Clone for RemotePromptContribution
impl Clone for RemotePromptContribution
Sourcefn clone(&self) -> RemotePromptContribution
fn clone(&self) -> RemotePromptContribution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemotePromptContribution
impl Debug for RemotePromptContribution
Sourceimpl<'de> Deserialize<'de> for RemotePromptContribution
impl<'de> Deserialize<'de> for RemotePromptContribution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemotePromptContribution
Sourceimpl JsonSchema for RemotePromptContribution
impl JsonSchema for RemotePromptContribution
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemotePromptContribution
impl PartialEq for RemotePromptContribution
Sourcefn eq(&self, other: &RemotePromptContribution) -> bool
fn eq(&self, other: &RemotePromptContribution) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemotePromptContribution
impl Serialize for RemotePromptContribution
impl StructuralPartialEq for RemotePromptContribution