pub struct RemotePromptTemplate {
pub sections: Vec<RemotePromptTemplateSection>,
}Fields
sections: Vec<RemotePromptTemplateSection>Trait Implementations
Sourceimpl Clone for RemotePromptTemplate
impl Clone for RemotePromptTemplate
Sourcefn clone(&self) -> RemotePromptTemplate
fn clone(&self) -> RemotePromptTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemotePromptTemplate
impl Debug for RemotePromptTemplate
Sourceimpl<'de> Deserialize<'de> for RemotePromptTemplate
impl<'de> Deserialize<'de> for RemotePromptTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemotePromptTemplate
Sourceimpl Hash for RemotePromptTemplate
impl Hash for RemotePromptTemplate
Sourceimpl JsonSchema for RemotePromptTemplate
impl JsonSchema for RemotePromptTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemotePromptTemplate
impl PartialEq for RemotePromptTemplate
Sourcefn eq(&self, other: &RemotePromptTemplate) -> bool
fn eq(&self, other: &RemotePromptTemplate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemotePromptTemplate
impl Serialize for RemotePromptTemplate
impl StructuralPartialEq for RemotePromptTemplate