pub struct RemotePromptTemplateSection {
pub title: Option<String>,
pub entries: Vec<RemotePromptTemplateEntry>,
}Fields
title: Option<String>entries: Vec<RemotePromptTemplateEntry>Trait Implementations
Sourceimpl Clone for RemotePromptTemplateSection
impl Clone for RemotePromptTemplateSection
Sourcefn clone(&self) -> RemotePromptTemplateSection
fn clone(&self) -> RemotePromptTemplateSection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemotePromptTemplateSection
impl Debug for RemotePromptTemplateSection
Sourceimpl<'de> Deserialize<'de> for RemotePromptTemplateSection
impl<'de> Deserialize<'de> for RemotePromptTemplateSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemotePromptTemplateSection
Sourceimpl Hash for RemotePromptTemplateSection
impl Hash for RemotePromptTemplateSection
Sourceimpl JsonSchema for RemotePromptTemplateSection
impl JsonSchema for RemotePromptTemplateSection
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemotePromptTemplateSection
impl PartialEq for RemotePromptTemplateSection
Sourcefn eq(&self, other: &RemotePromptTemplateSection) -> bool
fn eq(&self, other: &RemotePromptTemplateSection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemotePromptTemplateSection