pub struct RemoteProviderReasoningReplay {
pub item_id: Option<String>,
pub encrypted_content: Option<String>,
pub signature: Option<String>,
pub redacted: bool,
pub summary: Vec<String>,
}Fields
item_id: Option<String>encrypted_content: Option<String>signature: Option<String>redacted: boolsummary: Vec<String>Trait Implementations
Sourceimpl Clone for RemoteProviderReasoningReplay
impl Clone for RemoteProviderReasoningReplay
Sourcefn clone(&self) -> RemoteProviderReasoningReplay
fn clone(&self) -> RemoteProviderReasoningReplay
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RemoteProviderReasoningReplay
impl Default for RemoteProviderReasoningReplay
Sourcefn default() -> RemoteProviderReasoningReplay
fn default() -> RemoteProviderReasoningReplay
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteProviderReasoningReplay
impl<'de> Deserialize<'de> for RemoteProviderReasoningReplay
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteProviderReasoningReplay
Sourceimpl JsonSchema for RemoteProviderReasoningReplay
impl JsonSchema for RemoteProviderReasoningReplay
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteProviderReasoningReplay
impl PartialEq for RemoteProviderReasoningReplay
Sourcefn eq(&self, other: &RemoteProviderReasoningReplay) -> bool
fn eq(&self, other: &RemoteProviderReasoningReplay) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteProviderReasoningReplay