pub struct RemoteResponseTextMeta {
pub id: Option<String>,
pub status: Option<String>,
pub phase: Option<String>,
}Fields
id: Option<String>status: Option<String>phase: Option<String>Trait Implementations
Sourceimpl Clone for RemoteResponseTextMeta
impl Clone for RemoteResponseTextMeta
Sourcefn clone(&self) -> RemoteResponseTextMeta
fn clone(&self) -> RemoteResponseTextMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteResponseTextMeta
impl Debug for RemoteResponseTextMeta
Sourceimpl Default for RemoteResponseTextMeta
impl Default for RemoteResponseTextMeta
Sourcefn default() -> RemoteResponseTextMeta
fn default() -> RemoteResponseTextMeta
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteResponseTextMeta
impl<'de> Deserialize<'de> for RemoteResponseTextMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteResponseTextMeta
Sourceimpl JsonSchema for RemoteResponseTextMeta
impl JsonSchema for RemoteResponseTextMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteResponseTextMeta
impl PartialEq for RemoteResponseTextMeta
Sourcefn eq(&self, other: &RemoteResponseTextMeta) -> bool
fn eq(&self, other: &RemoteResponseTextMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteResponseTextMeta
impl Serialize for RemoteResponseTextMeta
impl StructuralPartialEq for RemoteResponseTextMeta