pub struct RemoteSchemaProjectionOverride {
pub profile: String,
pub schema: Value,
}Fields
profile: Stringschema: ValueTrait Implementations
Sourceimpl Clone for RemoteSchemaProjectionOverride
impl Clone for RemoteSchemaProjectionOverride
Sourcefn clone(&self) -> RemoteSchemaProjectionOverride
fn clone(&self) -> RemoteSchemaProjectionOverride
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RemoteSchemaProjectionOverride
impl<'de> Deserialize<'de> for RemoteSchemaProjectionOverride
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteSchemaProjectionOverride
Sourceimpl JsonSchema for RemoteSchemaProjectionOverride
impl JsonSchema for RemoteSchemaProjectionOverride
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteSchemaProjectionOverride
impl PartialEq for RemoteSchemaProjectionOverride
Sourcefn eq(&self, other: &RemoteSchemaProjectionOverride) -> bool
fn eq(&self, other: &RemoteSchemaProjectionOverride) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteSchemaProjectionOverride