pub struct RemoteSchemaProjectionPolicy {
pub mode: RemoteProjectionMode,
pub overrides: Vec<RemoteSchemaProjectionOverride>,
}Fields
mode: RemoteProjectionModeoverrides: Vec<RemoteSchemaProjectionOverride>Trait Implementations
Sourceimpl Clone for RemoteSchemaProjectionPolicy
impl Clone for RemoteSchemaProjectionPolicy
Sourcefn clone(&self) -> RemoteSchemaProjectionPolicy
fn clone(&self) -> RemoteSchemaProjectionPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteSchemaProjectionPolicy
impl Debug for RemoteSchemaProjectionPolicy
Sourceimpl<'de> Deserialize<'de> for RemoteSchemaProjectionPolicy
impl<'de> Deserialize<'de> for RemoteSchemaProjectionPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteSchemaProjectionPolicy
Sourceimpl JsonSchema for RemoteSchemaProjectionPolicy
impl JsonSchema for RemoteSchemaProjectionPolicy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteSchemaProjectionPolicy
impl PartialEq for RemoteSchemaProjectionPolicy
Sourcefn eq(&self, other: &RemoteSchemaProjectionPolicy) -> bool
fn eq(&self, other: &RemoteSchemaProjectionPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteSchemaProjectionPolicy