pub struct RemoteTokenLedgerEntry {
pub source: String,
pub model: String,
pub usage: RemoteUsage,
}Fields
source: Stringmodel: Stringusage: RemoteUsageTrait Implementations
Sourceimpl Clone for RemoteTokenLedgerEntry
impl Clone for RemoteTokenLedgerEntry
Sourcefn clone(&self) -> RemoteTokenLedgerEntry
fn clone(&self) -> RemoteTokenLedgerEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteTokenLedgerEntry
impl Debug for RemoteTokenLedgerEntry
Sourceimpl<'de> Deserialize<'de> for RemoteTokenLedgerEntry
impl<'de> Deserialize<'de> for RemoteTokenLedgerEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteTokenLedgerEntry
Sourceimpl JsonSchema for RemoteTokenLedgerEntry
impl JsonSchema for RemoteTokenLedgerEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteTokenLedgerEntry
impl PartialEq for RemoteTokenLedgerEntry
Sourcefn eq(&self, other: &RemoteTokenLedgerEntry) -> bool
fn eq(&self, other: &RemoteTokenLedgerEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteTokenLedgerEntry
impl Serialize for RemoteTokenLedgerEntry
impl StructuralPartialEq for RemoteTokenLedgerEntry