pub struct RemoteToolCallSummary {
pub call_id: Option<String>,
pub tool_name: String,
pub args: Value,
pub outcome: RemoteToolCallOutcome,
pub duration_ms: u64,
}Fields
call_id: Option<String>tool_name: Stringargs: Valueoutcome: RemoteToolCallOutcomeduration_ms: u64Trait Implementations
Sourceimpl Clone for RemoteToolCallSummary
impl Clone for RemoteToolCallSummary
Sourcefn clone(&self) -> RemoteToolCallSummary
fn clone(&self) -> RemoteToolCallSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteToolCallSummary
impl Debug for RemoteToolCallSummary
Sourceimpl<'de> Deserialize<'de> for RemoteToolCallSummary
impl<'de> Deserialize<'de> for RemoteToolCallSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteToolCallSummary
impl JsonSchema for RemoteToolCallSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteToolCallSummary
impl PartialEq for RemoteToolCallSummary
Sourcefn eq(&self, other: &RemoteToolCallSummary) -> bool
fn eq(&self, other: &RemoteToolCallSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteToolCallSummary
impl Serialize for RemoteToolCallSummary
impl StructuralPartialEq for RemoteToolCallSummary