pub struct RemoteTriggerOccurrenceRecord {
pub occurrence_id: String,
pub source_type: String,
pub source_key: String,
pub payload: Value,
pub idempotency_key: String,
pub source: Option<Value>,
pub occurred_at_ms: u64,
}Fields
occurrence_id: Stringsource_type: Stringsource_key: Stringpayload: Valueidempotency_key: Stringsource: Option<Value>occurred_at_ms: u64Trait Implementations
Sourceimpl Clone for RemoteTriggerOccurrenceRecord
impl Clone for RemoteTriggerOccurrenceRecord
Sourcefn clone(&self) -> RemoteTriggerOccurrenceRecord
fn clone(&self) -> RemoteTriggerOccurrenceRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RemoteTriggerOccurrenceRecord
impl<'de> Deserialize<'de> for RemoteTriggerOccurrenceRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteTriggerOccurrenceRecord
impl JsonSchema for RemoteTriggerOccurrenceRecord
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteTriggerOccurrenceRecord
impl PartialEq for RemoteTriggerOccurrenceRecord
Sourcefn eq(&self, other: &RemoteTriggerOccurrenceRecord) -> bool
fn eq(&self, other: &RemoteTriggerOccurrenceRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteTriggerOccurrenceRecord