pub struct RemoteTriggerRegistration {
pub handle: String,
pub source_key: String,
pub name: Option<String>,
pub source_type: String,
pub source: Value,
pub target: RemoteTriggerTargetSummary,
pub enabled: bool,
}Fields
handle: Stringsource_key: Stringname: Option<String>source_type: Stringsource: Valuetarget: RemoteTriggerTargetSummaryenabled: boolTrait Implementations
Sourceimpl Clone for RemoteTriggerRegistration
impl Clone for RemoteTriggerRegistration
Sourcefn clone(&self) -> RemoteTriggerRegistration
fn clone(&self) -> RemoteTriggerRegistration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteTriggerRegistration
impl Debug for RemoteTriggerRegistration
Sourceimpl<'de> Deserialize<'de> for RemoteTriggerRegistration
impl<'de> Deserialize<'de> for RemoteTriggerRegistration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteTriggerRegistration
impl JsonSchema for RemoteTriggerRegistration
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteTriggerRegistration
impl PartialEq for RemoteTriggerRegistration
Sourcefn eq(&self, other: &RemoteTriggerRegistration) -> bool
fn eq(&self, other: &RemoteTriggerRegistration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteTriggerRegistration