pub struct RemoteTurnIssue {
pub kind: String,
pub code: Option<String>,
pub terminal_reason: Option<RemoteLlmTerminalReason>,
pub message: String,
pub raw: Option<String>,
}Fields
kind: Stringcode: Option<String>terminal_reason: Option<RemoteLlmTerminalReason>message: Stringraw: Option<String>Trait Implementations
Sourceimpl Clone for RemoteTurnIssue
impl Clone for RemoteTurnIssue
Sourcefn clone(&self) -> RemoteTurnIssue
fn clone(&self) -> RemoteTurnIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteTurnIssue
impl Debug for RemoteTurnIssue
Sourceimpl<'de> Deserialize<'de> for RemoteTurnIssue
impl<'de> Deserialize<'de> for RemoteTurnIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteTurnIssue
impl JsonSchema for RemoteTurnIssue
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteTurnIssue
impl PartialEq for RemoteTurnIssue
Sourcefn eq(&self, other: &RemoteTurnIssue) -> bool
fn eq(&self, other: &RemoteTurnIssue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteTurnIssue
impl Serialize for RemoteTurnIssue
impl StructuralPartialEq for RemoteTurnIssue