pub struct RemoteTriggerDeliveryEmitReport {
pub occurrence_id: String,
pub subscription_id: String,
pub process_id: String,
pub outcome: RemoteTriggerDeliveryEmitOutcome,
}Fields
occurrence_id: Stringsubscription_id: Stringprocess_id: Stringoutcome: RemoteTriggerDeliveryEmitOutcomeTrait Implementations
Sourceimpl Clone for RemoteTriggerDeliveryEmitReport
impl Clone for RemoteTriggerDeliveryEmitReport
Sourcefn clone(&self) -> RemoteTriggerDeliveryEmitReport
fn clone(&self) -> RemoteTriggerDeliveryEmitReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RemoteTriggerDeliveryEmitReport
impl<'de> Deserialize<'de> for RemoteTriggerDeliveryEmitReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteTriggerDeliveryEmitReport
Sourceimpl JsonSchema for RemoteTriggerDeliveryEmitReport
impl JsonSchema for RemoteTriggerDeliveryEmitReport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RemoteTriggerDeliveryEmitReport